@@ -458,7 +458,7 @@ QString sftpProtocol::canonicalizePath(const QString &path) {
 sftpProtocol::sftpProtocol(const QByteArray &pool_socket, const QByteArray &app_socket)
              : SlaveBase("kio_sftp", pool_socket, app_socket),
                mConnected(false), mPort(-1), mSession(NULL), mSftp(NULL), mPublicKeyAuthInfo(0) {
-#ifndef Q_WS_WIN
+#ifndef Q_OS_WIN
   qCDebug(KIO_SMTP_LOG) << "pid = " << getpid();
 
   qCDebug(KIO_SMTP_LOG) << "debug = " << getenv("KIO_SFTP_LOG_VERBOSITY");
@@ -503,7 +503,7 @@ sftpProtocol::sftpProtocol(const QByteArray &pool_socket, const QByteArray &app_
 }
 
 sftpProtocol::~sftpProtocol() {
-#ifndef Q_WS_WIN
+#ifndef Q_OS_WIN
   qCDebug(KIO_SMTP_LOG) << "pid = " << getpid();
 #endif
   closeConnection();
