@@ -26,7 +26,7 @@
     #include <machine/param.h>
 #endif
 #include <sys/types.h>
-#ifndef Q_WS_WIN
+#ifndef Q_OS_WIN
 #include <sys/ipc.h>
 #include <sys/shm.h>
 #endif
@@ -38,6 +38,7 @@
 #include <QBitmap>
 #include <QCryptographicHash>
 #include <QImage>
+#include <QIcon>
 #include <QPainter>
 #include <QPixmap>
 #include <QUrl>
@@ -318,7 +319,7 @@ void ThumbnailProtocol::get(const QUrl &url)
             data(imgData);
         }
     } else {
-#ifndef Q_WS_WIN
+#ifndef Q_OS_WIN
         QByteArray imgData;
         QDataStream stream( &imgData, QIODevice::WriteOnly );
         //qDebug() << "IMAGE TO SHMID";
@@ -466,9 +467,8 @@ QImage ThumbnailProtocol::thumbForDirectory(const QUrl& directory)
     const QMimeDatabase db;
     const QString iconName = db.mimeTypeForName("inode/directory").iconName();
 
-    const QPixmap folder = KIconLoader::global()->loadMimeTypeIcon(iconName,
-                                                                   KIconLoader::Desktop,
-                                                                   qMin(m_width, m_height));
+    const QPixmap folder = QIcon::fromTheme(iconName).pixmap(qMin(m_width, m_height));
+
     const int folderWidth  = folder.width();
     const int folderHeight = folder.height();
 
